summaryrefslogtreecommitdiffstats
path: root/board/amcc
diff options
context:
space:
mode:
authorMike Nuss <mike@terascala.com>2008-02-06 11:10:11 -0500
committerStefan Roese <sr@denx.de>2008-02-16 07:00:03 +0100
commitb738654d3c84a30f2bfd9a8d7652ff20807c890c (patch)
tree7476e09c8214e5184d538b8210354dcfe436915c /board/amcc
parentef5b4f221c22d05770878513951745f236b5b43f (diff)
downloadblackbird-obmc-uboot-b738654d3c84a30f2bfd9a8d7652ff20807c890c.tar.gz
blackbird-obmc-uboot-b738654d3c84a30f2bfd9a8d7652ff20807c890c.zip
PPC440EPx: Optionally enable second I2C bus
The option CONFIG_I2C_MULTI_BUS does not have any effect on Sequoia, the PPC440EPx reference platform, because IIC1 is never enabled. Add Sequoia board code to turn on IIC1 if CONFIG_I2C_MULTI_BUS is selected. Signed-off-by: Mike Nuss <mike@terascala.com> Cc: Stefan Roese <sr@denx.de>
Diffstat (limited to 'board/amcc')
-rw-r--r--board/amcc/sequoia/sequoia.c5
1 files changed, 4 insertions, 1 deletions
diff --git a/board/amcc/sequoia/sequoia.c b/board/amcc/sequoia/sequoia.c
index 57905de623..6bcb3ab198 100644
--- a/board/amcc/sequoia/sequoia.c
+++ b/board/amcc/sequoia/sequoia.c
@@ -86,10 +86,13 @@ int board_early_init_f(void)
/* enable USB device */
out_8((u8 *) CFG_BCSR_BASE + 0x09, 0x20);
/* select Ethernet pins */
mfsdr(SDR0_PFC1, sdr0_pfc1);
sdr0_pfc1 = (sdr0_pfc1 & ~SDR0_PFC1_SELECT_MASK) |
SDR0_PFC1_SELECT_CONFIG_4;
+#ifdef CONFIG_I2C_MULTI_BUS
+ sdr0_pfc1 |= ((sdr0_pfc1 & ~SDR0_PFC1_SIS_MASK) | SDR0_PFC1_SIS_IIC1_SEL);
+#endif
mfsdr(SDR0_PFC2, sdr0_pfc2);
sdr0_pfc2 = (sdr0_pfc2 & ~SDR0_PFC2_SELECT_MASK) |
SDR0_PFC2_SELECT_CONFIG_4;
@@ -86,10 +86,13 @@ int board_early_init_f(void)
/* enable USB device */
out_8((u8 *) CFG_BCSR_BASE + 0x09, 0x20);
- /* select Ethernet pins */
+ /* select Ethernet (and optionally IIC1) pins */
mfsdr(SDR0_PFC1, sdr0_pfc1);
sdr0_pfc1 = (sdr0_pfc1 & ~SDR0_PFC1_SELECT_MASK) |
OpenPOWER on IntegriCloud